# Table of Contents

- [application-modernization-understand-strategy](<./application-modernization-understand-strategy.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Step 1: Understand Your Strategy](<./Step-1-Understand-Your-Strategy.md>)
  - [Define “Modern”](<./Step-1-Understand-Your-Strategy/Define-Modern.md>)
  - [Identify Stakeholders](<./Step-1-Understand-Your-Strategy/Identify-Stakeholders.md>)
  - [Align on KPIs and OKRs](<./Step-1-Understand-Your-Strategy/Align-on-KPIs-and-OKRs.md>)
  - [Set the Timeline](<./Step-1-Understand-Your-Strategy/Set-the-Timeline.md>)
  - [Example](<./Step-1-Understand-Your-Strategy/Example.md>)
  - [Was this page helpful?](<./Step-1-Understand-Your-Strategy/Was-this-page-helpful.md>)
